"""
Icon.py
by Jason Conti
February 22, 2010

Utility functions for working with icons.
"""

import gc
import gtk
import logging
import os

icon_cache = {}
logger = logging.getLogger("Icon")

def clear_icon_cache():
  """Clear the icon cache, garbage collecting all the icons."""
  global icon_cache
  for icon in icon_cache.values():
    del icon
  icon_cache = {}
  gc.collect()

def load_icon(name, size = 48):
  """Loads an icon from the default icon theme."""
  global icon_cache
  if (name, size, 0) in icon_cache:
    return icon_cache[(name, size, 0)]
  else:
    try:
      theme = gtk.icon_theme_get_default()
      icon = theme.load_icon(name, size, gtk.ICON_LOOKUP_FORCE_SVG)
      icon_cache[(name, size, 0)] = icon
      return icon
    except:
      logger.exception("failed to load_icon {0}".format(name))
      return None

def load_icon_from_file(path, size = 48):
  """Loads an icon from the given path."""
  global icon_cache

  try:
    mtime = os.path.getmtime(path)
  except:
    logger.exception("failed to get mtime for {0}".format(path))
    return None

  if (path, size, mtime) in icon_cache:
    logger.debug("loading {0} from cache (mtime = {1})".format(path, mtime))
    return icon_cache[(path, size, mtime)]
  else:
    logger.debug("cache miss on {0} (mtime = {1})".format(path, mtime))
    try:
      icon = gtk.gdk.pixbuf_new_from_file_at_size(path, size, size)
      icon_cache[(path, size, mtime)] = icon
      return icon
    except:
      logger.exception("failed to load_icon_from_file for {0}".format(path))
      return None

